import datetime
import argparse
from sys import stdin, stdout
"""
WikiTable - convert a .csv file (tab separated)
            to Wiki table format. 
"""
class WikiTable():
    def __init__(self):
	pass

    def __version__(self):
        return "1.0.0"

    def readinputfile(self, file_name = None):
        if (file_name == None):
            csv_file = stdin
        else:
            csv_file = open(file_name, "r")
        csv_text = csv_file.read()
        csv_file.close()
        return csv_text

    def convert_to_wiki_table(self, csv_text, headers = False):
        wikitext = "{|class='wikitable' border='1'\n"
        needHeader = headers
        temp = csv_text.splitlines(True)
        for line in temp:
            line = line.strip()
            linecells = line.split('\t')
            firstCell = True
            for cells in linecells:
                if (firstCell or needHeader):
                    wikitext += '|'
                else:
                    wikitext += '||'
                if (needHeader):
                    wikitext += "align='left' style='background:#f0f0f0;'|'''"
                    wikitext += cells
                    wikitext += "'''\n" 
                else:
                    wikitext += cells
                firstCell = False
            if (needHeader):
                needHeader = False
                wikitext += '|-\n'
            else:
                wikitext+='\n|-\n'
        wikitext += "|}\n"
        return wikitext
            

    def write_wiki_text_file(self, text, wikitext_file_name = None):
        if (wikitext_file_name == None):
            f = stdout
            f.write(text)
        else:
            with open(wikitext_file_name, 'w') as f:
                f.write(text)

    def appMain(self, inputfile, outputfile, headers):
        test = self.readinputfile(inputfile)
        wtest = self.convert_to_wiki_table(test, headers)
        self.write_wiki_text_file(wtest, outputfile)
        
"""
The main app class.
Only gets called if this file is running stand alone, and
not if it's included as part of a larger application
"""
class theApp():        
    def __init__(self):
        self.appMain()

    def getVersion(self):
        vapp = WikiTable()
        version = '%(prog) s ' + vapp.__version__()
        return version        

    def getArgs(self):
        parser = argparse.ArgumentParser()
        parser.add_argument('-v', '--version', action='version', version = self.getVersion())
        parser.add_argument("-i", "--inputfile", default=None,
            help="Specifies the .csv input file name.")
        parser.add_argument("-o", "--outputfile", default=None,
            help="Specifies the output file name for resulting Wiki page source code.")
        parser.add_argument("-t", "--tableheaders", default=False,
            help="-t True specifies table includes a header row.")
        args = parser.parse_args()
        return args

    def appMain(self):
        args = self.getArgs()
        app = WikiTable()
        app.appMain(args.inputfile, args.outputfile, args.tableheaders)

"""
Main program - run stand-alone if not included as part of a larger application
"""
if __name__ == '__main__':
   app = theApp()
  
   
